@@ -1,7 +1,7 @@
 static const char *petscmachineinfo = "\n"
 "-----------------------------------------\n"
-"Libraries compiled on 2025-10-19 13:01:16 on reproducible\n"
-"Machine characteristics: Linux-6.14.0-1012-azure-x86_64-with-glibc2.42\n"
+"Libraries compiled on 2025-11-02 20:27:42 on reproducible\n"
+"Machine characteristics: Linux-6.11.0-1018-azure-x86_64-with-glibc2.42\n"
 "Using PETSc directory: /opt/petsc/linux-c-opt\n"
 "Using PETSc arch: \n"
 "-----------------------------------------\n";
@@ -15,5 +15,5 @@ static const char *petsccompilerflagsinfo = "\n"
 static const char *petsclinkerinfo = "\n"
 "Using C linker: /usr/bin/mpicc\n"
 "Using Fortran linker: /usr/bin/mpif90\n"
-"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lsuperlu -llapack -lblas -lzfp -lptesmumps -lptscotchparmetisv3 -lptscotch -lptscotcherr -lesmumps -lscotch -lscotcherr -lnetcdf -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -lgsl -lgslcblas -lm -lz -ljpeg -lyaml -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
+"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lpastix -lsuperlu -llapack -lblas -lzfp -lesmumps -lptscotch -lptscotcherr -lscotch -lscotcherr -lnetcdf -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -lgsl -lgslcblas -lm -lz -ljpeg -lyaml -lhwloc -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
 "-----------------------------------------\n";
